@@ -11,7 +11,9 @@
 #' @param tidy Should the results come back in a tibble (`TRUE`) or a `conf_mat`
 #' object like `yardstick::conf_mat()` (`FALSE`)?
 #' @return A tibble or `conf_mat` with the average cell count across resamples.
-#' @examples
+#' @examplesIf rlang::is_installed("modeldata")
+#' # example code
+#'
 #' library(parsnip)
 #' library(rsample)
 #' library(dplyr)
@@ -20,8 +22,8 @@
 #'
 #' set.seed(2393)
 #' res <-
-#'   logistic_reg() %>%
-#'   set_engine("glm") %>%
+#'   logistic_reg() |>
+#'   set_engine("glm") |>
 #'   fit_resamples(
 #'     Class ~ .,
 #'     resamples = vfold_cv(two_class_dat, v = 3),
@@ -34,63 +36,66 @@
 conf_mat_resampled <- function(x, ..., parameters = NULL, tidy = TRUE) {
   rlang::check_dots_empty()
   if (!inherits(x, "tune_results")) {
-    rlang::abort(
-      "The first argument needs to be an object with class 'tune_results'."
+    cli::cli_abort(
+      "The first argument needs to be {.cls tune_results} object,
+                   not {.obj_type_friendly {mtcars}}."
     )
   }
   if (!any(names(x) == ".predictions")) {
-    rlang::abort(
-      paste0(
-        "The function was not run with the `save_pred = TRUE` option. ",
-        "Please re-run with that option."
-      )
+    cli::cli_abort(
+      "The function was not run with the {.code save_pred = TRUE} option.
+       Please re-run with that option."
     )
   }
   preds <- collect_predictions(x, summarize = FALSE, parameters = parameters)
 
   if (!any(names(preds) == ".pred_class")) {
-    rlang::abort("Cannot find the predicted classes. Was this a classification model?")
+    cli::cli_abort(
+      "Cannot find the predicted classes. Was this a classification model?"
+    )
   }
   # check for multiple parameter combinations
   params <- .get_tune_parameter_names(x)
   if (length(params) > 0) {
     param_combos <-
-      preds %>%
-      dplyr::select(!!!params) %>%
+      preds |>
+      dplyr::select(!!!params) |>
       distinct()
     if (nrow(param_combos) > 1) {
-      rlang::abort(
-        paste0(
-          "It looks like there are ", nrow(param_combos), " tuning parameter ",
-          "combination(s) in the data. Please use the `parameters` ",
-          "argument to select one combination of parameters."
-        )
+      cli::cli_abort(
+        "It looks like there are {nrow(param_combos)} tuning parameter
+        combination in the data. Please use the {.arg parameters}
+        argument to select one combination of parameters."
       )
     }
   }
 
   truth <- .get_tune_outcome_names(x)
   if (length(truth) != 1) {
-    rlang::abort("Cannot determine the proper outcome name")
+    cli::cli_abort("Cannot determine the proper outcome name")
   }
 
   id_cols <- grep("(^id$)|($id[1-9]$)", names(preds), value = TRUE)
   preds <-
-    preds %>%
-    dplyr::group_nest(!!!syms(id_cols)) %>%
+    preds |>
+    dplyr::group_nest(!!!syms(id_cols)) |>
     dplyr::mutate(
-      conf_mats =
-        purrr::map(data, ~ yardstick::conf_mat(.x, truth = {{ truth }}, estimate = .pred_class))
+      conf_mats = purrr::map(
+        data,
+        \(.x) {
+          yardstick::conf_mat(.x, truth = {{ truth }}, estimate = .pred_class)
+        }
+      )
     )
 
   opt <- getOption("dplyr.summarise.inform", default = "FALSE")
   options(dplyr.summarise.inform = FALSE)
 
   res <-
-    purrr::map(preds$conf_mats, ~ as.data.frame(.x$table)) %>%
-    purrr::list_rbind() %>%
-    dplyr::group_by(Prediction, Truth) %>%
-    dplyr::summarize(Freq = mean(Freq, na.rm = TRUE)) %>%
+    purrr::map(preds$conf_mats, \(.x) as.data.frame(.x$table)) |>
+    purrr::list_rbind() |>
+    dplyr::group_by(Prediction, Truth) |>
+    dplyr::summarize(Freq = mean(Freq, na.rm = TRUE)) |>
     dplyr::ungroup()
 
   options(dplyr.summarise.inform = opt)
@@ -100,7 +105,7 @@ conf_mat_resampled <- function(x, ..., parameters = NULL, tidy = TRUE) {
     res <- matrix(res$Freq, ncol = length(lvls), byrow = TRUE)
     colnames(res) <- lvls
     rownames(res) <- lvls
-    res <- as.table(res) %>% yardstick::conf_mat()
+    res <- as.table(res) |> yardstick::conf_mat()
   }
   res
 }
