@@ -13,15 +13,15 @@
 #'
 #' @return A tibble with a column `x` that has as many rows as were in `y`.
 #' @keywords internal
-#' @examplesIf tune:::should_run_examples(suggests = c("xgboost", "modeldata"))
+#' @examplesIf tune:::should_run_examples(suggests = c("xgboost", "modeldata", "splines2"))
 #' library(tibble)
 #' library(recipes)
 #' library(parsnip)
 #' library(dials)
 #'
 #' pca_rec <-
-#'   recipe(mpg ~ ., data = mtcars) %>%
-#'   step_impute_knn(all_predictors(), neighbors = tune()) %>%
+#'   recipe(mpg ~ ., data = mtcars) |>
+#'   step_impute_knn(all_predictors(), neighbors = tune()) |>
 #'   step_pca(all_predictors(), num_comp = tune())
 #'
 #' pca_grid <-
@@ -36,9 +36,9 @@
 #' merge(pca_rec, pca_grid)
 #'
 #' spline_rec <-
-#'   recipe(mpg ~ ., data = mtcars) %>%
-#'   step_ns(disp, deg_free = tune("disp df")) %>%
-#'   step_ns(wt, deg_free = tune("wt df"))
+#'   recipe(mpg ~ ., data = mtcars) |>
+#'   step_spline_natural(disp, deg_free = tune("disp df")) |>
+#'   step_spline_natural(wt, deg_free = tune("wt df"))
 #'
 #' spline_grid <-
 #'   tribble(
@@ -54,13 +54,13 @@
 #' data(hpc_data, package = "modeldata")
 #'
 #' xgb_mod <-
-#'   boost_tree(trees = tune(), min_n = tune()) %>%
+#'   boost_tree(trees = tune(), min_n = tune()) |>
 #'   set_engine("xgboost")
 #'
 #' set.seed(254)
 #' xgb_grid <-
-#'   extract_parameter_set_dials(xgb_mod) %>%
-#'   finalize(hpc_data) %>%
+#'   extract_parameter_set_dials(xgb_mod) |>
+#'   finalize(hpc_data) |>
 #'   grid_max_entropy(size = 3)
 #'
 #' merge(xgb_mod, xgb_grid)
@@ -77,10 +77,9 @@ merge.model_spec <- function(x, y, ...) {
 
 update_model <- function(grid, object, pset, step_id, nms, ...) {
   for (i in nms) {
-    param_info <- pset %>% dplyr::filter(id == i & source == "model_spec")
+    param_info <- pset |> dplyr::filter(id == i & source == "model_spec")
     if (nrow(param_info) > 1) {
-      # TODO figure this out and write a better message
-      rlang::abort("There are too many things.")
+      cli::cli_abort("Cannot update; there are too many parameters.")
     }
     if (nrow(param_info) == 1) {
       if (param_info$component_id == "main") {
@@ -97,7 +96,7 @@ update_model <- function(grid, object, pset, step_id, nms, ...) {
 
 update_recipe <- function(grid, object, pset, step_id, nms, ...) {
   for (i in nms) {
-    param_info <- pset %>% dplyr::filter(id == i & source == "recipe")
+    param_info <- pset |> dplyr::filter(id == i & source == "recipe")
     if (nrow(param_info) == 1) {
       idx <- which(step_id == param_info$component_id)
       # check index
@@ -111,37 +110,38 @@ update_recipe <- function(grid, object, pset, step_id, nms, ...) {
 
 merger <- function(x, y, ...) {
   if (!is.data.frame(y)) {
-    rlang::abort("The second argument should be a data frame.")
+    cli::cli_abort("The second argument should be a data frame.")
   }
   pset <- hardhat::extract_parameter_set_dials(x)
 
   if (nrow(pset) == 0) {
-    res <- purrr::map(seq_len(nrow(y)), ~x)
+    res <- purrr::map(seq_len(nrow(y)), \(.x) x)
     res <- tibble::new_tibble(list(x = res), nrow = length(res))
     return(res)
   }
   grid_name <- colnames(y)
   # We will deliberately allow `y` to lack some tunable parameters in `x`
 
-
   if (inherits(x, "recipe")) {
     updater <- update_recipe
-    step_ids <- purrr::map_chr(x$steps, ~ .x$id)
+    step_ids <- purrr::map_chr(x$steps, "id")
   } else {
     updater <- update_model
     step_ids <- NULL
   }
 
   if (!any(grid_name %in% pset$id)) {
-    res <- purrr::map(seq_len(nrow(y)), ~ x)
+    res <- purrr::map(seq_len(nrow(y)), \(.x) x)
     res <- tibble::new_tibble(list(x = res), nrow = length(res))
     return(res)
   }
 
-  y %>%
+  y |>
     dplyr::mutate(
-      ..object = purrr::map(1:nrow(y), ~ updater(y[.x,], x, pset, step_ids, grid_name))
-    ) %>%
+      ..object = purrr::map(
+        1:nrow(y),
+        \(.x) updater(y[.x, ], x, pset, step_ids, grid_name)
+      )
+    ) |>
     dplyr::select(x = ..object)
 }
-
