@@ -6,8 +6,8 @@
 #' @keywords internal
 #' @examples
 #' library(dplyr)
-#' lm(cbind(mpg, wt) ~ ., data = mtcars) %>%
-#'   purrr::pluck(terms) %>%
+#' lm(cbind(mpg, wt) ~ ., data = mtcars) |>
+#'   purrr::pluck(terms) |>
 #'   outcome_names()
 #' @export
 outcome_names <- function(x, ...) {
@@ -40,12 +40,12 @@ outcome_names.recipe <- function(x, ...) {
 #' @export
 #' @rdname outcome_names
 outcome_names.workflow <- function(x, ...) {
-  if (!is.null(x$fit$fit)) {
+  if (!is.null(x$pre$mold)) {
     y_vals <- extract_mold(x)$outcomes
     res <- colnames(y_vals)
   } else {
     preprocessor <- extract_preprocessor(x)
-    res <- outcome_names(preprocessor)
+    res <- outcome_names(preprocessor, ...)
   }
   res
 }
@@ -61,3 +61,15 @@ outcome_names.tune_results <- function(x, ...) {
   }
   res
 }
+
+#' @export
+#' @rdname outcome_names
+outcome_names.workflow_variables <- function(x, data = NULL, ...) {
+  if (!inherits(data, "data.frame")) {
+    cli::cli_abort(
+      "When using {.fn outcome_names} on an object for class {.cls {class(x)}}, the
+      argument {.arg data} should be a data frame, not {.obj_type_friendly {data}}."
+    )
+  }
+  names(dplyr::select(data, !!x$outcomes))
+}
