@@ -1,4 +1,3 @@
-
 #' @importFrom dials parameters
 #' @export
 dials::parameters
@@ -35,6 +34,10 @@ generics::augment
 #' @export
 rsample::.get_fingerprint
 
+#' @importFrom rsample int_pctl
+#' @export
+rsample::int_pctl
+
 #' @importFrom hardhat extract_spec_parsnip
 #' @export
 hardhat::extract_spec_parsnip
