@@ -11,9 +11,18 @@ library(tune)
 # Since they have been undependable on this, we'll avoid running all tests on
 # CRAN.
 
-if (identical(Sys.getenv("NOT_CRAN"), "true")) { # emulates `testthat:::on_cran()`
+if (identical(Sys.getenv("NOT_CRAN"), "true")) {
+  # emulates `testthat:::on_cran()`
   if (requireNamespace("xml2")) {
-    test_check("tune", reporter = MultiReporter$new(reporters = list(JunitReporter$new(file = "test-results.xml"), CheckReporter$new())))
+    test_check(
+      "tune",
+      reporter = MultiReporter$new(
+        reporters = list(
+          JunitReporter$new(file = "test-results.xml"),
+          CheckReporter$new()
+        )
+      )
+    )
   } else {
     test_check("tune")
   }
