@@ -1,34 +1,39 @@
-
 test_that("tune recipe only", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
   set.seed(363)
   mt_folds <- rsample::vfold_cv(mtcars, v = 5)
 
   extr_1_1 <- function(x) {
-    extract_recipe(x) %>% tidy(number = 2)
+    extract_recipe(x) |> tidy(number = 2)
   }
   before_kind <- RNGkind()[[1]]
-  expect_error(
+  expect_no_error(
     res_1_1 <-
-      workflow() %>%
-      add_recipe(helper_objects$rec_tune_1) %>%
-      add_model(helper_objects$lm_mod) %>%
-      tune_grid(resamples = mt_folds, control = control_grid(extract = extr_1_1)),
-    NA
+      workflow() |>
+      add_recipe(helper_objects$rec_tune_1) |>
+      add_model(helper_objects$lm_mod) |>
+      tune_grid(
+        resamples = mt_folds,
+        control = control_grid(extract = extr_1_1)
+      )
   )
   after_kind <- RNGkind()[[1]]
   expect_equal(before_kind, after_kind)
-  expect_error(extract_1_1 <- dplyr::bind_rows(res_1_1$.extracts), NA)
+  expect_no_error(extract_1_1 <- dplyr::bind_rows(res_1_1$.extracts))
 
   expect_true(all(names(extract_1_1) == c("num_comp", ".extracts", ".config")))
   expect_true(
-    all(purrr::map_lgl(extract_1_1$.extracts, ~ tibble::is_tibble(.x))),
+    all(purrr::map_lgl(extract_1_1$.extracts, tibble::is_tibble)),
   )
 })
 
 # ------------------------------------------------------------------------------
 
 test_that("tune model only", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
   set.seed(363)
   mt_folds <- rsample::vfold_cv(mtcars, v = 5)
@@ -38,26 +43,28 @@ test_that("tune model only", {
     tibble(index = mod@alphaindex[[1]], estimate = mod@coef[[1]])
   }
 
-  expect_error(
+  expect_no_error(
     res_2_1 <-
-      workflow() %>%
-      add_recipe(helper_objects$rec_no_tune_1) %>%
-      add_model(helper_objects$svm_mod) %>%
+      workflow() |>
+      add_recipe(helper_objects$rec_no_tune_1) |>
+      add_model(helper_objects$svm_mod) |>
       tune_grid(
         resamples = mt_folds,
         grid = 2,
         control = control_grid(extract = extr_2_1)
-      ),
-    NA
+      )
   )
-  expect_error(extract_2_1 <- dplyr::bind_rows(res_2_1$.extracts), NA)
+  expect_no_error(extract_2_1 <- dplyr::bind_rows(res_2_1$.extracts))
 
   expect_true(all(names(extract_2_1) == c("cost", ".extracts", ".config")))
   expect_true(
-    all(purrr::map_lgl(extract_2_1$.extracts, ~ tibble::is_tibble(.x))),
+    all(purrr::map_lgl(extract_2_1$.extracts, tibble::is_tibble)),
   )
   expect_true(
-    all(purrr::map_lgl(extract_2_1$.extracts, ~ all(names(.x) == c("index", "estimate")))),
+    all(purrr::map_lgl(
+      extract_2_1$.extracts,
+      \(.x) all(names(.x) == c("index", "estimate"))
+    )),
   )
 
   extr_2_2 <- function(x) {
@@ -65,24 +72,22 @@ test_that("tune model only", {
   }
 
   # should not fail:
-  expect_error(
+  expect_no_error(
     res_2_2 <-
-      workflow() %>%
-      add_recipe(helper_objects$rec_tune_1) %>%
-      add_model(helper_objects$lm_mod) %>%
+      workflow() |>
+      add_recipe(helper_objects$rec_tune_1) |>
+      add_model(helper_objects$lm_mod) |>
       tune_grid(
         resamples = mt_folds,
         grid = 2,
         control = control_grid(extract = extr_2_2)
-      ),
-    NA
+      )
   )
 
-  expect_error(
+  expect_no_error(
     extract_2_2 <-
-      dplyr::bind_rows(res_2_2$.extracts) %>%
-      tidyr::unnest(cols = c(.extracts)),
-    NA
+      dplyr::bind_rows(res_2_2$.extracts) |>
+      tidyr::unnest(cols = c(.extracts))
   )
   expect_true(all(!extract_2_2$is_null_rec))
 })
@@ -97,9 +102,19 @@ test_that("mis-specified extract function", {
   set.seed(1)
   boots <- rsample::bootstraps(mtcars, 3)
 
-  raise_warning <- function(x) {warning("AHHH"); TRUE}
-  raise_error <- function(x) {stop("AHHH"); TRUE}
-  raise_both <- function(x) {warning("AH"); stop("AHHH"); TRUE}
+  raise_warning <- function(x) {
+    warning("AHHH")
+    TRUE
+  }
+  raise_error <- function(x) {
+    stop("AHHH")
+    TRUE
+  }
+  raise_both <- function(x) {
+    warning("AH")
+    stop("AHHH")
+    TRUE
+  }
   raise_error_once <- local({
     first <- TRUE
 
@@ -115,22 +130,42 @@ test_that("mis-specified extract function", {
 
   expect_snapshot(
     res_extract_warning <-
-      fit_resamples(wf, boots, control = control_resamples(extract = raise_warning))
+      fit_resamples(
+        wf,
+        boots,
+        control = control_resamples(extract = raise_warning)
+      ),
+    transform = catalog_lines
   )
 
   expect_snapshot(
     res_extract_error <-
-      fit_resamples(wf, boots, control = control_resamples(extract = raise_error))
+      fit_resamples(
+        wf,
+        boots,
+        control = control_resamples(extract = raise_error)
+      ),
+    transform = catalog_lines
   )
 
   expect_snapshot(
     res_extract_both <-
-      fit_resamples(wf, boots, control = control_resamples(extract = raise_both))
+      fit_resamples(
+        wf,
+        boots,
+        control = control_resamples(extract = raise_both)
+      ),
+    transform = catalog_lines
   )
 
   expect_snapshot(
     res_extract_error_once <-
-      fit_resamples(wf, boots, control = control_resamples(extract = raise_error_once))
+      fit_resamples(
+        wf,
+        boots,
+        control = control_resamples(extract = raise_error_once)
+      ),
+    transform = catalog_lines
   )
 
   expect_snapshot(res_extract_warning)
@@ -154,6 +189,8 @@ test_that("mis-specified extract function", {
 # ------------------------------------------------------------------------------
 
 test_that("tune model and recipe", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
   set.seed(363)
   mt_folds <- rsample::vfold_cv(mtcars, v = 5)
@@ -163,35 +200,33 @@ test_that("tune model and recipe", {
   }
 
   wflow_3 <-
-    workflow() %>%
-    add_recipe(helper_objects$rec_tune_1) %>%
+    workflow() |>
+    add_recipe(helper_objects$rec_tune_1) |>
     add_model(helper_objects$svm_mod)
   set.seed(35)
   grid_3 <-
-    extract_parameter_set_dials(wflow_3) %>%
-    update(num_comp = dials::num_comp(c(2, 5))) %>%
+    extract_parameter_set_dials(wflow_3) |>
+    update(num_comp = dials::num_comp(c(2, 5))) |>
     dials::grid_space_filling(size = 4)
 
-  expect_error(
+  expect_no_error(
     res_3_1 <- tune_grid(
       wflow_3,
       resamples = mt_folds,
       grid = grid_3,
       control = control_grid(extract = extr_3_1)
-    ),
-    NA
+    )
   )
-  expect_error(extract_3_1 <- dplyr::bind_rows(res_3_1$.extracts), NA)
+  expect_no_error(extract_3_1 <- dplyr::bind_rows(res_3_1$.extracts))
 
-  expect_true(all(names(extract_3_1) == c("num_comp", "cost", ".extracts", ".config")))
+  expect_named(extract_3_1, c("cost", "num_comp", ".extracts", ".config"))
   expect_true(
-    all(purrr::map_lgl(extract_3_1$.extracts, ~ inherits(.x, "workflow"))),
+    all(purrr::map_lgl(extract_3_1$.extracts, inherits, "workflow")),
   )
 })
 
 # ------------------------------------------------------------------------------
 
-
 test_that("check .config in extracts", {
   load(test_path("data", "test_objects.RData"))
 
@@ -206,14 +241,14 @@ test_that("check .config in extracts", {
 
   recipe_only_configs <-
     full_join(
-      mt_spln_lm_bo %>%
-        filter(id == first(id)) %>%
-        select(.iter, .metrics) %>%
-        unnest(cols = .metrics) %>%
+      mt_spln_lm_bo |>
+        filter(id == first(id)) |>
+        select(.iter, .metrics) |>
+        unnest(cols = .metrics) |>
         filter(.metric == first(.metric)),
-      mt_spln_lm_bo %>%
-        filter(id == first(id)) %>%
-        select(.iter, .extracts) %>%
+      mt_spln_lm_bo |>
+        filter(id == first(id)) |>
+        select(.iter, .extracts) |>
         unnest(cols = .extracts),
       by = c(".iter", "deg_free")
     )
