@@ -1,11 +1,13 @@
 test_that("tune recipe only", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_tune_1) |>
     add_model(helper_objects$lm_mod)
-  pset <- extract_parameter_set_dials(wflow) %>%
+  pset <- extract_parameter_set_dials(wflow) |>
     update(num_comp = dials::num_comp(c(1, 3)))
   grid <- dials::grid_regular(pset, levels = 3)
   folds <- rsample::vfold_cv(mtcars)
@@ -34,11 +36,13 @@ test_that("tune recipe only", {
 # ------------------------------------------------------------------------------
 
 test_that("tune model only (with recipe)", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_no_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_no_tune_1) |>
     add_model(helper_objects$svm_mod)
   pset <- extract_parameter_set_dials(wflow)
   grid <- dials::grid_regular(pset, levels = 3)
@@ -65,12 +69,14 @@ test_that("tune model only (with recipe)", {
 # ------------------------------------------------------------------------------
 
 test_that("tune model only (with variables)", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
 
-  wflow <- workflow() %>%
-    add_variables(mpg, everything()) %>%
+  wflow <- workflow() |>
+    add_variables(mpg, everything()) |>
     add_model(helper_objects$svm_mod)
 
   pset <- extract_parameter_set_dials(wflow)
@@ -93,11 +99,13 @@ test_that("tune model only (with variables)", {
 # ------------------------------------------------------------------------------
 
 test_that("tune model only (with recipe, multi-predict)", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_no_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_no_tune_1) |>
     add_model(helper_objects$svm_mod)
   pset <- extract_parameter_set_dials(wflow)
   grid <- dials::grid_regular(pset, levels = 3)
@@ -135,6 +143,7 @@ test_that("tune model only (without recipe, multi-predict. #695)", {
 test_that("tune model only (fairness - include `by` variable as predictor)", {
   skip_on_cran()
   skip_if_not_installed("yardstick", minimum_version = "1.2.0.9001")
+  skip_if_not_installed("kknn")
 
   knn <- parsnip::nearest_neighbor("classification", "kknn", neighbors = tune())
   mtcars_fair <- mtcars
@@ -147,12 +156,14 @@ test_that("tune model only (fairness - include `by` variable as predictor)", {
 
   set.seed(1)
   res <- tune_grid(
-    knn, vs ~ mpg + hp + cyl, resamples = boots, grid = n_grid,
-    metrics =
-      yardstick::metric_set(
-        yardstick::roc_auc,
-        yardstick::demographic_parity(cyl)
-      )
+    knn,
+    vs ~ mpg + hp + cyl,
+    resamples = boots,
+    grid = n_grid,
+    metrics = yardstick::metric_set(
+      yardstick::roc_auc,
+      yardstick::demographic_parity(cyl)
+    )
   )
 
   expect_equal(
@@ -162,7 +173,16 @@ test_that("tune model only (fairness - include `by` variable as predictor)", {
   res_est <- collect_metrics(res)
   expect_equal(
     colnames(res_est),
-    c("neighbors", ".metric", ".estimator", ".by", "mean", "n", "std_err", ".config")
+    c(
+      "neighbors",
+      ".metric",
+      ".estimator",
+      ".by",
+      "mean",
+      "n",
+      "std_err",
+      ".config"
+    )
   )
   expect_equal(nrow(res_est), n_grid * 2)
   expect_equal(sum(res_est$.by == "cyl", na.rm = TRUE), n_grid)
@@ -175,6 +195,7 @@ test_that("tune model only (fairness - include `by` variable as predictor)", {
 test_that("tune model only (fairness - don't include `by` variable as predictor)", {
   skip_on_cran()
   skip_if_not_installed("yardstick", minimum_version = "1.2.0.9001")
+  skip_if_not_installed("kknn")
 
   knn <- parsnip::nearest_neighbor("classification", "kknn", neighbors = tune())
   mtcars_fair <- mtcars
@@ -187,12 +208,14 @@ test_that("tune model only (fairness - don't include `by` variable as predictor)
 
   set.seed(1)
   res2 <- tune_grid(
-    knn, vs ~ mpg + hp, resamples = boots, grid = n_grid,
-    metrics =
-      yardstick::metric_set(
-        yardstick::roc_auc,
-        yardstick::demographic_parity(cyl)
-      )
+    knn,
+    vs ~ mpg + hp,
+    resamples = boots,
+    grid = n_grid,
+    metrics = yardstick::metric_set(
+      yardstick::roc_auc,
+      yardstick::demographic_parity(cyl)
+    )
   )
 
   expect_equal(
@@ -202,7 +225,16 @@ test_that("tune model only (fairness - don't include `by` variable as predictor)
   res_est2 <- collect_metrics(res2)
   expect_equal(
     colnames(res_est2),
-    c("neighbors", ".metric", ".estimator", ".by", "mean", "n", "std_err", ".config")
+    c(
+      "neighbors",
+      ".metric",
+      ".estimator",
+      ".by",
+      "mean",
+      "n",
+      "std_err",
+      ".config"
+    )
   )
   expect_equal(nrow(res_est2), n_grid * 2)
   expect_equal(sum(res_est2$.by == "cyl", na.rm = TRUE), n_grid)
@@ -215,6 +247,7 @@ test_that("tune model only (fairness - don't include `by` variable as predictor)
 test_that("tune model only (fairness metrics - evaluate across multiple `by`)", {
   skip_on_cran()
   skip_if_not_installed("yardstick", minimum_version = "1.2.0.9001")
+  skip_if_not_installed("kknn")
 
   knn <- parsnip::nearest_neighbor("classification", "kknn", neighbors = tune())
   mtcars_fair <- mtcars
@@ -227,13 +260,15 @@ test_that("tune model only (fairness metrics - evaluate across multiple `by`)",
 
   set.seed(1)
   res3 <- tune_grid(
-    knn, vs ~ mpg + hp, resamples = boots, grid = n_grid,
-    metrics =
-      yardstick::metric_set(
-        yardstick::roc_auc,
-        yardstick::demographic_parity(cyl),
-        yardstick::equal_opportunity(am)
-      )
+    knn,
+    vs ~ mpg + hp,
+    resamples = boots,
+    grid = n_grid,
+    metrics = yardstick::metric_set(
+      yardstick::roc_auc,
+      yardstick::demographic_parity(cyl),
+      yardstick::equal_opportunity(am)
+    )
   )
 
   expect_equal(
@@ -243,7 +278,16 @@ test_that("tune model only (fairness metrics - evaluate across multiple `by`)",
   res_est3 <- collect_metrics(res3)
   expect_equal(
     colnames(res_est3),
-    c("neighbors", ".metric", ".estimator", ".by", "mean", "n", "std_err", ".config")
+    c(
+      "neighbors",
+      ".metric",
+      ".estimator",
+      ".by",
+      "mean",
+      "n",
+      "std_err",
+      ".config"
+    )
   )
   expect_equal(nrow(res_est3), n_grid * 3)
   expect_equal(sum(res_est3$.by == "cyl", na.rm = TRUE), n_grid)
@@ -256,6 +300,7 @@ test_that("tune model only (fairness metrics - evaluate across multiple `by`)",
 test_that("tune model only (fairness - evaluate across multiple `by`, same metric)", {
   skip_on_cran()
   skip_if_not_installed("yardstick", minimum_version = "1.2.0.9001")
+  skip_if_not_installed("kknn")
 
   knn <- parsnip::nearest_neighbor("classification", "kknn", neighbors = tune())
   mtcars_fair <- mtcars
@@ -268,13 +313,15 @@ test_that("tune model only (fairness - evaluate across multiple `by`, same metri
 
   set.seed(1)
   res4 <- tune_grid(
-    knn, vs ~ mpg + hp, resamples = boots, grid = n_grid,
-    metrics =
-      yardstick::metric_set(
-        yardstick::roc_auc,
-        yardstick::demographic_parity(cyl),
-        yardstick::demographic_parity(am)
-      )
+    knn,
+    vs ~ mpg + hp,
+    resamples = boots,
+    grid = n_grid,
+    metrics = yardstick::metric_set(
+      yardstick::roc_auc,
+      yardstick::demographic_parity(cyl),
+      yardstick::demographic_parity(am)
+    )
   )
 
   expect_equal(
@@ -284,7 +331,16 @@ test_that("tune model only (fairness - evaluate across multiple `by`, same metri
   res_est4 <- collect_metrics(res4)
   expect_equal(
     colnames(res_est4),
-    c("neighbors", ".metric", ".estimator", ".by", "mean", "n", "std_err", ".config")
+    c(
+      "neighbors",
+      ".metric",
+      ".estimator",
+      ".by",
+      "mean",
+      "n",
+      "std_err",
+      ".config"
+    )
   )
   expect_equal(nrow(res_est4), n_grid * 3)
   expect_equal(sum(res_est4$.by == "cyl", na.rm = TRUE), n_grid)
@@ -298,6 +354,7 @@ test_that("tune model only (fairness - evaluate across multiple `by`, same metri
 test_that("tune model only (fairness - evaluate only fairness metrics)", {
   skip_on_cran()
   skip_if_not_installed("yardstick", minimum_version = "1.2.0.9001")
+  skip_if_not_installed("kknn")
 
   knn <- parsnip::nearest_neighbor("classification", "kknn", neighbors = tune())
   mtcars_fair <- mtcars
@@ -310,11 +367,13 @@ test_that("tune model only (fairness - evaluate only fairness metrics)", {
 
   set.seed(1)
   res5 <- tune_grid(
-    knn, vs ~ mpg + hp, resamples = boots, grid = n_grid,
-    metrics =
-      yardstick::metric_set(
-        yardstick::demographic_parity(cyl)
-      )
+    knn,
+    vs ~ mpg + hp,
+    resamples = boots,
+    grid = n_grid,
+    metrics = yardstick::metric_set(
+      yardstick::demographic_parity(cyl)
+    )
   )
 
   expect_equal(
@@ -324,7 +383,16 @@ test_that("tune model only (fairness - evaluate only fairness metrics)", {
   res_est5 <- collect_metrics(res5)
   expect_equal(
     colnames(res_est5),
-    c("neighbors", ".metric", ".estimator", ".by", "mean", "n", "std_err", ".config")
+    c(
+      "neighbors",
+      ".metric",
+      ".estimator",
+      ".by",
+      "mean",
+      "n",
+      "std_err",
+      ".config"
+    )
   )
   expect_equal(nrow(res_est5), n_grid)
   expect_equal(sum(res_est5$.by == "cyl", na.rm = TRUE), n_grid)
@@ -336,13 +404,15 @@ test_that("tune model only (fairness - evaluate only fairness metrics)", {
 # ------------------------------------------------------------------------------
 
 test_that("tune model and recipe", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_tune_1) |>
     add_model(helper_objects$svm_mod)
-  pset <- extract_parameter_set_dials(wflow) %>%
+  pset <- extract_parameter_set_dials(wflow) |>
     update(num_comp = dials::num_comp(c(1, 3)))
   grid <- dials::grid_regular(pset, levels = 3)
   folds <- rsample::vfold_cv(mtcars)
@@ -376,13 +446,15 @@ test_that("tune model and recipe", {
 # ------------------------------------------------------------------------------
 
 test_that("tune model and recipe (multi-predict)", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_tune_1) |>
     add_model(helper_objects$svm_mod)
-  pset <- extract_parameter_set_dials(wflow) %>%
+  pset <- extract_parameter_set_dials(wflow) |>
     update(num_comp = dials::num_comp(c(2, 3)))
   grid <- dials::grid_regular(pset, levels = c(3, 2))
   folds <- rsample::vfold_cv(mtcars)
@@ -398,13 +470,15 @@ test_that("tune model and recipe (multi-predict)", {
 # ------------------------------------------------------------------------------
 
 test_that('tune model and recipe (parallel_over = "everything")', {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_tune_1) |>
     add_model(helper_objects$svm_mod)
-  pset <- extract_parameter_set_dials(wflow) %>%
+  pset <- extract_parameter_set_dials(wflow) |>
     update(num_comp = dials::num_comp(c(1, 3)))
   grid <- dials::grid_regular(pset, levels = 3)
   folds <- rsample::vfold_cv(mtcars)
@@ -427,15 +501,18 @@ test_that('tune model and recipe (parallel_over = "everything")', {
 # ------------------------------------------------------------------------------
 
 test_that("tune recipe only - failure in recipe is caught elegantly", {
+  skip_if_not_installed("splines2")
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(7898)
   data_folds <- rsample::vfold_cv(mtcars, v = 2)
 
-  rec <- recipe(mpg ~ ., data = mtcars) %>%
-    step_bs(disp, deg_free = tune())
+  rec <- recipe(mpg ~ ., data = mtcars) |>
+    step_spline_b(disp, deg_free = tune())
 
-  model <- linear_reg(mode = "regression") %>%
+  model <- linear_reg(mode = "regression") |>
     set_engine("lm")
 
   # NA values not allowed in recipe
@@ -475,14 +552,17 @@ test_that("tune recipe only - failure in recipe is caught elegantly", {
 })
 
 test_that("tune model only - failure in recipe is caught elegantly", {
+  skip_if_not_installed("splines2")
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(7898)
   data_folds <- rsample::vfold_cv(mtcars, v = 2)
 
   # NA values not allowed in recipe
-  rec <- recipe(mpg ~ ., data = mtcars) %>%
-    step_bs(disp, deg_free = NA_real_)
+  rec <- recipe(mpg ~ ., data = mtcars) |>
+    step_spline_b(disp, deg_free = NA_real_)
 
   cars_grid <- tibble(cost = c(0.01, 0.02))
 
@@ -492,7 +572,12 @@ test_that("tune model only - failure in recipe is caught elegantly", {
       preprocessor = rec,
       resamples = data_folds,
       grid = cars_grid,
-      control = control_grid(extract = function(x) {1}, save_pred = TRUE)
+      control = control_grid(
+        extract = function(x) {
+          1
+        },
+        save_pred = TRUE
+      )
     )
   )
 
@@ -510,6 +595,8 @@ test_that("tune model only - failure in recipe is caught elegantly", {
 })
 
 test_that("tune model only - failure in formula is caught elegantly", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(7898)
@@ -524,8 +611,14 @@ test_that("tune model only - failure in formula is caught elegantly", {
       y ~ z,
       resamples = data_folds,
       grid = cars_grid,
-      control = control_grid(extract = function(x) {1}, save_pred = TRUE)
-    )
+      control = control_grid(
+        extract = function(x) {
+          1
+        },
+        save_pred = TRUE
+      )
+    ),
+    transform = catalog_lines
   )
 
   notes <- cars_res$.notes
@@ -542,14 +635,16 @@ test_that("tune model only - failure in formula is caught elegantly", {
 })
 
 test_that("tune model and recipe - failure in recipe is caught elegantly", {
+  skip_if_not_installed("splines2")
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(7898)
   data_folds <- rsample::vfold_cv(mtcars, v = 2)
 
-  rec <- recipe(mpg ~ ., data = mtcars) %>%
-    step_bs(disp, deg_free = tune())
-
+  rec <- recipe(mpg ~ ., data = mtcars) |>
+    step_spline_b(disp, deg_free = tune())
 
   # NA values not allowed in recipe
   cars_grid <- tibble(deg_free = c(NA_real_, 10L), cost = 0.01)
@@ -560,7 +655,12 @@ test_that("tune model and recipe - failure in recipe is caught elegantly", {
       preprocessor = rec,
       resamples = data_folds,
       grid = cars_grid,
-      control = control_grid(extract = function(x) {1}, save_pred = TRUE)
+      control = control_grid(
+        extract = function(x) {
+          1
+        },
+        save_pred = TRUE
+      )
     )
   })
 
@@ -584,6 +684,8 @@ test_that("tune model and recipe - failure in recipe is caught elegantly", {
 })
 
 test_that("argument order gives errors for recipes", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   expect_snapshot(error = TRUE, {
@@ -596,6 +698,8 @@ test_that("argument order gives errors for recipes", {
 })
 
 test_that("argument order gives errors for formula", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   expect_snapshot(error = TRUE, {
@@ -604,10 +708,12 @@ test_that("argument order gives errors for formula", {
 })
 
 test_that("ellipses with tune_grid", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_tune_1) |>
     add_model(helper_objects$lm_mod)
   folds <- rsample::vfold_cv(mtcars)
   expect_snapshot(
@@ -627,13 +733,14 @@ test_that("determining the grid type", {
 })
 
 
-
 test_that("retain extra attributes", {
+  skip_if_not_installed("kernlab")
+
   helper_objects <- helper_objects_tune()
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_recipe(helper_objects$rec_no_tune_1) %>%
+  wflow <- workflow() |>
+    add_recipe(helper_objects$rec_no_tune_1) |>
     add_model(helper_objects$svm_mod)
   pset <- extract_parameter_set_dials(wflow)
   grid <- dials::grid_regular(pset, levels = 3)
@@ -652,8 +759,8 @@ test_that("retain extra attributes", {
   expect_true(inherits(att$metrics, "metric_set"))
 
   set.seed(4400)
-  wflow <- workflow() %>%
-    add_formula(mpg ~ .) %>%
+  wflow <- workflow() |>
+    add_formula(mpg ~ .) |>
     add_model(helper_objects$svm_mod)
   pset <- extract_parameter_set_dials(wflow)
   grid <- dials::grid_regular(pset, levels = 3)
@@ -680,8 +787,8 @@ test_that("retain extra attributes", {
   expect_null(attr(res, "workflow"))
   expect_true(inherits(attr(res2, "workflow"), "workflow"))
 
-  wflow2 <- workflow() %>%
-    add_recipe(recipes::recipe(mpg ~ ., mtcars[rep(1:32, 3000), ])) %>%
+  wflow2 <- workflow() |>
+    add_recipe(recipes::recipe(mpg ~ ., mtcars[rep(1:32, 3000), ])) |>
     add_model(helper_objects$svm_mod)
   pset2 <- extract_parameter_set_dials(wflow2)
   grid2 <- dials::grid_regular(pset2, levels = 3)
@@ -696,5 +803,3 @@ test_that("retain extra attributes", {
     "being saved contains a recipe, which is"
   )
 })
-
-
